# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------

r"""
Do not modify; this file is autogenerated by azureml-core\scripts\generate_constants.py.

To add error codes, please refer to error_handling\readme.md in the Vienna/specs repository.
"""


class ErrorCodes:
    """Constants for error codes."""

    # Any errors due to the user. Whether its due to input settings, the environment they provide, etc.
    USER_ERROR = "UserError"

    # User errors that we can validate before submitting.
    VALIDATION_ERROR = "ValidationError"

    BADARGUMENT_ERROR = "BadArgument"

    CONFLICTINGSETTINGS_ERROR = "ConflictingSettings"

    INVALID_ERROR = "Invalid"

    MALFORMED_ERROR = "Malformed"

    BLANKOREMPTY_ERROR = "BlankOrEmpty"

    OUTOFRANGE_ERROR = "OutOfRange"

    NOTFOUND_ERROR = "NotFound"

    # Errors that occur due to user provided data.
    DATAVALIDATION_ERROR = "DataValidation"

    INVALIDDATATYPE_ERROR = "InvalidDataType"

    # The family of exception codes, missing special column types.
    MISSINGCOLUMN_ERROR = "MissingColumn"

    DATASHAPE_ERROR = "DataShape"

    # X and y do not have the same number of samples, or do not have any samples.
    DATASAMPLESMISMATCH_ERROR = "DataSamplesMismatch"

    INVALIDDATA_ERROR = "InvalidData"

    # The label column is not found in input data.
    INPUTLABELMISSING_ERROR = "InputLabelMissing"

    # The combination of time and grain index is not unique.
    DUPLICATEDINDEX_ERROR = "DuplicatedIndex"

    # Data frame is irregular or frequency can not be established.
    TIMEFREQUENCYCANNOTBEINFERRABLE_ERROR = "TimeFrequencyCanNotBeInferrable"

    # The Time is not continuous between train and validate/test sets.
    TIMENOTCONTINUOUS_ERROR = "TimeNotContinuous"

    # Time frequencies in train and validate/test are different.
    FREQUENCIESMISMATCH_ERROR = "FrequenciesMismatch"

    #  One of the grains from validate/test set is absent in the training set.
    GRAINISABSENT_ERROR = "GrainIsAbsent"

    # The data entry is not hashable.
    UNHASHABLEENTRY_ERROR = "UnhashableEntry"

    # The input data is empty.
    EMPTYDATA_ERROR = "EmptyData"

    # The input data is insufficient.
    INSUFFICIENTDATA_ERROR = "InsufficientData"

    # The input data contains out of bound data.
    OUTOFBOUNDDATA_ERROR = "OutOfBoundData"

    # Input data format not as expected
    DATAFORMAT_ERROR = "DataFormat"

    # Input data has all missing labels
    ALLLABELSMISSING_ERROR = "AllLabelsMissing"

    SCENARIONOTSUPORTED_ERROR = "ScenarioNotSuported"

    NOTIMPLEMENTED_ERROR = "NotImplemented"

    # Code for implicit dependencies not on the user's environment.
    OPTIONALSCENARIONOTENABLED_ERROR = "OptionalScenarioNotEnabled"

    INVALIDRUNSTATE_ERROR = "InvalidRunState"

    # Advanced featurization or feature sweeping is not supported on local compute.
    ADVANCEDFEATURIZATIONNOTSUPPORTED_ERROR = "AdvancedFeaturizationNotSupported"

    # Advanced forecasting models such as Prophet or ARIMA are not supported on local compute.
    ADVANCEDFORECASTINGMODELSNOTSUPPORTED_ERROR = "AdvancedForecastingModelsNotSupported"

    # Continue run is not supported on local compute.
    CONTINUERUNNOTSUPPORTED_ERROR = "ContinueRunNotSupported"

    # Featurization customization is not supported on local compute.
    CUSTOMFEATURIZATIONNOTSUPPORTED_ERROR = "CustomFeaturizationNotSupported"

    # Deep learning is not supported on local compute.
    DEEPLEARNINGNOTSUPPORTED_ERROR = "DeepLearningNotSupported"

    # Ensembles are not supported on local compute.
    ENSEMBLENOTSUPPORTED_ERROR = "EnsembleNotSupported"

    # Local compute experiment time is limited.
    EXPERIMENTTIMEOUTREACHED_ERROR = "ExperimentTimeoutReached"

    # Number of trials on local compute is limited.
    MAXNUMBEROFTRIALSREACHED_ERROR = "MaxNumberOfTrialsReached"

    # Model explainability is not supported on local compute.
    MODELEXPLAINABILITYNOTSUPPORTED_ERROR = "ModelExplainabilityNotSupported"

    # Number of samples supported on local compute is limited.
    NUMBEROFSAMPLESEXCEEDED_ERROR = "NumberOfSamplesExceeded"

    # ONNX conversion is not supported on local compute.
    ONNXNOTSUPPORTED_ERROR = "ONNXNotSupported"

    # Data streaming is not supported on local compute.
    STREAMINGNOTSUPPORTED_ERROR = "StreamingNotSupported"

    # Subsampling is not supported on local compute.
    SUBSAMPLINGNOTSUPPORTED_ERROR = "SubsamplingNotSupported"

    # Code for forecasting specific configuration errors.
    FORECASTINGCONFIG_ERROR = "ForecastingConfig"

    # Special column is marked to be dropped.
    SPECIALCOLUMNDROP_ERROR = "SpecialColumnDrop"

    # Time column is present in the list of grain columns.
    TIMEANDGRAINSOVERLAP_ERROR = "TimeAndGrainsOverlap"

    # Not supported type of a column name.
    COLUMNNAMENOTSUPPORTED_ERROR = "ColumnNameNotSupported"

    # Code for configuration errors.
    CONFIG_ERROR = "Config"

    # Featurization needs to be enabled.
    FEATURIZATIONOFF_ERROR = "FeaturizationOff"

    AUTHENTICATION_ERROR = "Authentication"

    # Thrown when user is not authorized to perform certain action.
    AUTHORIZATION_ERROR = "AuthorizationError"

    # User workspace does not have access to this feature.
    FEATUREUNAVAILABLE_ERROR = "FeatureUnavailableError"

    # If a user throws a keyboard exception.
    KEYBOARDEXCEPTION_ERROR = "KeyboardException"

    # If the run stops early. Should usually be a warning rather than an error.
    EARLYTERMINATION_ERROR = "EarlyTermination"

    # Insufficient memory during operation.
    INSUFFICIENTMEMORY_ERROR = "InsufficientMemory"

    # No disk space left during operation.
    DISKSPACEUNVAILABLE_ERROR = "DiskSpaceUnvailable"

    # Any errors due to our systems such as services, SDK, or UI.
    SYSTEM_ERROR = "System"

    #  Error for bad predictions from models used within our product (not user models). E.g. AutoML uses an ML model
    # to predict future iterations, if that model fails to get a new model, it would throw a Prediction
    PREDICTION_ERROR = "Prediction"

    #  Errors for components outside of our ownership. E.g. Scikit or Pandas. This is especially relevent if we want
    # to treat some of these as warnings to the user and continue execution.
    EXTERNAL_ERROR = "External"

    #  Fit errors in third party components. E.g. Xgboost and Scikit. This should be used as a catch all for
    # pipeline.fit() failures outside of azureml control.
    FIT_ERROR = "Fit"

    #  Transform errors in third party components. E.g. Scikit. This should be used as a catch all for
    # pipeline.transform() failures outside of azureml control.
    TRANSFORM_ERROR = "Transform"

    # Errors and exceptions thrown when processing data during training or inferencing.
    DATA_ERROR = "DataError"

    # Errors seen while creating the raw data snapshot during training time which is used at the inference time.
    RAWDATASNAPSHOT_ERROR = "RawDataSnapShot"

    # Errors thrown from the operating system.
    OS_ERROR = "Os"

    FILE_ERROR = "File"

    FILENOTFOUND_ERROR = "FileNotFound"

    DELETE_ERROR = "Delete"

    MEMORY_ERROR = "Memory"

    # If other process is unexpectedly killed by the OS.
    PROCESSKILLED_ERROR = "ProcessKilled"

    # Errors thrown from the service.
    SERVICE_ERROR = "Service"

    # Thrown when service api invocation fails.
    APIINVOCATION_ERROR = "ApiInvocation"

    # Errors thrown by Jasmine API calls.
    JASMINESERVICE_ERROR = "JasmineService"

    # Error thrown when Jasmine fails to fetch the next iteration.
    FETCHNEXTITERATION_ERROR = "FetchNextIteration"

    # In the unlikely event that the service finds missing run state.
    MISSINGSTATE_ERROR = "MissingState"

    # In the unlikely event that the service finds invalid run state.
    INVALIDSTATE_ERROR = "InvalidState"

    # The service failed to change the run state.
    STATECHANGE_ERROR = "StateChange"

    # Errors thrown by Dataset Service API calls.
    DATASETSERVICE_ERROR = "DatasetService"

    # Errors encountered during execution of an AutoML pipeline
    PIPELINEEXECUTION_ERROR = "PipelineExecution"

    # AutoML Ensembling related errors.
    AUTOMLENSEMBLE_ERROR = "AutoMLEnsemble"

    # Errors thrown from the client.
    CLIENT_ERROR = "Client"

    # The exceptions during data transform runtime.
    TRANSFORMRUNTIME_ERROR = "TransformRuntime"

    # The argument is invalid.
    BADTRANSFORMARGUMENT_ERROR = "BadTransformArgument"

    # The argument is invalid input.
    INVALIDTRANSFORMARGUMENT_ERROR = "InvalidTransformArgument"

    DATATRANSFORMERUNKNOWNTASK_ERROR = "DataTransformerUnknownTask"

    MODELINGBERTNOAPEXINVALIDHIDDENSIZE_ERROR = "ModelingBertNoApexInvalidHiddenSize"

    UNRECOGNIZEDTRANSFORMEDFEATURENAME_ERROR = "UnrecognizedTransformedFeatureName"

    UNRECOGNIZEDRAWFEATUREALIASNAME_ERROR = "UnrecognizedRawFeatureAliasName"

    # The argument type is invalid.
    INVALIDTRANSFORMARGUMENTTYPE_ERROR = "InvalidTransformArgumentType"

    MODELINGBERTNOAPEXNOTINTORSTR_ERROR = "ModelingBertNoApexNotIntOrStr"

    NIMBUSMLTEXTTARGETENCODERFEATURIZERINVALIDTYPE_ERROR = "NimbusMlTextTargetEncoderFeaturizerInvalidType"

    NIMBUSMLTEXTTARGETENCODERLEARNERINVALIDTYPE_ERROR = "NimbusMlTextTargetEncoderLearnerInvalidType"

    # The argument type is malformed inside transformation.
    MALFORMEDTRANSFORMARGUMENT_ERROR = "MalformedTransformArgument"

    ENGINEEREDFEATURENAMESNOTRANSFORMATIONSINJSON_ERROR = "EngineeredFeatureNamesNoTransformationsInJson"

    # The argument is not supported.
    NOTSUPPORTEDTRANSFORMARGUMENT_ERROR = "NotSupportedTransformArgument"

    ENGINEEREDFEATURENAMESUNSUPPORTEDINDEX_ERROR = "EngineeredFeatureNamesUnsupportedIndex"

    ENGINEEREDFEATURENAMESNOTSUPPORTEDFEATURETYPE_ERROR = "EngineeredFeatureNamesNotSupportedFeatureType"

    PRETRAINEDTEXTDNNTRANSFORMERFITUNSUPPORTEDTASK_ERROR = "PretrainedTextDnnTransformerFitUnsupportedTask"

    PRETRAINEDTEXTDNNTRANSFORMERCONVERTUNSUPPORTEDTASK_ERROR = "PretrainedTextDnnTransformerConvertUnsupportedTask"

    # The transform argument is blank or empty.
    BLANKOREMPTYTRANSFORMARGUMENT_ERROR = "BlankOrEmptyTransformArgument"

    ENGINEEREDFEATURENAMESEMPTYJSON_ERROR = "EngineeredFeatureNamesEmptyJson"

    ENGINEEREDFEATURENAMESNORAWFEATURETYPE_ERROR = "EngineeredFeatureNamesNoRawFeatureType"

    ENGINEEREDFEATURENAMESTRANSFORMERNAMESNOTFOUND_ERROR = "EngineeredFeatureNamesTransformerNamesNotFound"

    # The data is invalid.
    INVALIDTRANSFORMDATA_ERROR = "InvalidTransformData"

    # The transform data shape is invalid.
    TRANSFORMDATASHAPE_ERROR = "TransformDataShapeError"

    DATATRANSFORMERINCONSISTENTROWCOUNT_ERROR = "DataTransformerInconsistentRowCount"

    # The data tranformer runtime is not called before use.
    TRANSFORMERRUNTIMENOTCALLED_ERROR = "TransformerRuntimeNotCalled"

    CATIMPUTERRUNTIMENOTCALLED_ERROR = "CatImputerRuntimeNotCalled"

    CROSSVALIDATIONTARGETIMPUTERRUNTIMENOTCALLED_ERROR = "CrossValidationTargetImputerRuntimeNotCalled"

    BINTRANSFORMERRUNTIMENOTCALLED_ERROR = "BinTransformerRuntimeNotCalled"

    # The exceptions ONNX runtime.
    ONNXRUNTIME_ERROR = "ONNXRuntime"

    # The model for ONNX is invalid.
    INVALIDONNXMODEL_ERROR = "InvalidONNXModel"

    # The data for ONNX is invalid.
    INVALIDONNXINPUTDATA_ERROR = "InvalidONNXInputData"

    # The data type for ONNX is invalid.
    INVALIDONNXINPUTDATATYPE_ERROR = "InvalidONNXInputDataType"


class ErrorHierarchy:
    """Constants containing full error hierarchies."""

    USER_ERROR = [
        ErrorCodes.USER_ERROR,
    ]
    VALIDATION_ERROR = [
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    BADARGUMENT_ERROR = [
        ErrorCodes.BADARGUMENT_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    CONFLICTINGSETTINGS_ERROR = [
        ErrorCodes.CONFLICTINGSETTINGS_ERROR,
        ErrorCodes.BADARGUMENT_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    INVALID_ERROR = [
        ErrorCodes.INVALID_ERROR,
        ErrorCodes.BADARGUMENT_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    MALFORMED_ERROR = [
        ErrorCodes.MALFORMED_ERROR,
        ErrorCodes.BADARGUMENT_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    BLANKOREMPTY_ERROR = [
        ErrorCodes.BLANKOREMPTY_ERROR,
        ErrorCodes.BADARGUMENT_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    OUTOFRANGE_ERROR = [
        ErrorCodes.OUTOFRANGE_ERROR,
        ErrorCodes.BADARGUMENT_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    NOTFOUND_ERROR = [
        ErrorCodes.NOTFOUND_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    DATAVALIDATION_ERROR = [
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    INVALIDDATATYPE_ERROR = [
        ErrorCodes.INVALIDDATATYPE_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    MISSINGCOLUMN_ERROR = [
        ErrorCodes.MISSINGCOLUMN_ERROR,
        ErrorCodes.INVALIDDATA_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    DATASHAPE_ERROR = [
        ErrorCodes.DATASHAPE_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    DATASAMPLESMISMATCH_ERROR = [
        ErrorCodes.DATASAMPLESMISMATCH_ERROR,
        ErrorCodes.DATASHAPE_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    INVALIDDATA_ERROR = [
        ErrorCodes.INVALIDDATA_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    INPUTLABELMISSING_ERROR = [
        ErrorCodes.INPUTLABELMISSING_ERROR,
        ErrorCodes.MISSINGCOLUMN_ERROR,
        ErrorCodes.INVALIDDATA_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    DUPLICATEDINDEX_ERROR = [
        ErrorCodes.DUPLICATEDINDEX_ERROR,
        ErrorCodes.INVALIDDATA_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    TIMEFREQUENCYCANNOTBEINFERRABLE_ERROR = [
        ErrorCodes.TIMEFREQUENCYCANNOTBEINFERRABLE_ERROR,
        ErrorCodes.INVALIDDATA_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    TIMENOTCONTINUOUS_ERROR = [
        ErrorCodes.TIMENOTCONTINUOUS_ERROR,
        ErrorCodes.INVALIDDATA_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    FREQUENCIESMISMATCH_ERROR = [
        ErrorCodes.FREQUENCIESMISMATCH_ERROR,
        ErrorCodes.INVALIDDATA_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    GRAINISABSENT_ERROR = [
        ErrorCodes.GRAINISABSENT_ERROR,
        ErrorCodes.INVALIDDATA_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    UNHASHABLEENTRY_ERROR = [
        ErrorCodes.UNHASHABLEENTRY_ERROR,
        ErrorCodes.INVALIDDATA_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    EMPTYDATA_ERROR = [
        ErrorCodes.EMPTYDATA_ERROR,
        ErrorCodes.INVALIDDATA_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    INSUFFICIENTDATA_ERROR = [
        ErrorCodes.INSUFFICIENTDATA_ERROR,
        ErrorCodes.INVALIDDATA_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    OUTOFBOUNDDATA_ERROR = [
        ErrorCodes.OUTOFBOUNDDATA_ERROR,
        ErrorCodes.INVALIDDATA_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    DATAFORMAT_ERROR = [
        ErrorCodes.DATAFORMAT_ERROR,
        ErrorCodes.INVALIDDATA_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    ALLLABELSMISSING_ERROR = [
        ErrorCodes.ALLLABELSMISSING_ERROR,
        ErrorCodes.DATAVALIDATION_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    SCENARIONOTSUPORTED_ERROR = [
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    NOTIMPLEMENTED_ERROR = [
        ErrorCodes.NOTIMPLEMENTED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    OPTIONALSCENARIONOTENABLED_ERROR = [
        ErrorCodes.OPTIONALSCENARIONOTENABLED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    INVALIDRUNSTATE_ERROR = [
        ErrorCodes.INVALIDRUNSTATE_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    ADVANCEDFEATURIZATIONNOTSUPPORTED_ERROR = [
        ErrorCodes.ADVANCEDFEATURIZATIONNOTSUPPORTED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    ADVANCEDFORECASTINGMODELSNOTSUPPORTED_ERROR = [
        ErrorCodes.ADVANCEDFORECASTINGMODELSNOTSUPPORTED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    CONTINUERUNNOTSUPPORTED_ERROR = [
        ErrorCodes.CONTINUERUNNOTSUPPORTED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    CUSTOMFEATURIZATIONNOTSUPPORTED_ERROR = [
        ErrorCodes.CUSTOMFEATURIZATIONNOTSUPPORTED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    DEEPLEARNINGNOTSUPPORTED_ERROR = [
        ErrorCodes.DEEPLEARNINGNOTSUPPORTED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    ENSEMBLENOTSUPPORTED_ERROR = [
        ErrorCodes.ENSEMBLENOTSUPPORTED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    EXPERIMENTTIMEOUTREACHED_ERROR = [
        ErrorCodes.EXPERIMENTTIMEOUTREACHED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    MAXNUMBEROFTRIALSREACHED_ERROR = [
        ErrorCodes.MAXNUMBEROFTRIALSREACHED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    MODELEXPLAINABILITYNOTSUPPORTED_ERROR = [
        ErrorCodes.MODELEXPLAINABILITYNOTSUPPORTED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    NUMBEROFSAMPLESEXCEEDED_ERROR = [
        ErrorCodes.NUMBEROFSAMPLESEXCEEDED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    ONNXNOTSUPPORTED_ERROR = [
        ErrorCodes.ONNXNOTSUPPORTED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    STREAMINGNOTSUPPORTED_ERROR = [
        ErrorCodes.STREAMINGNOTSUPPORTED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    SUBSAMPLINGNOTSUPPORTED_ERROR = [
        ErrorCodes.SUBSAMPLINGNOTSUPPORTED_ERROR,
        ErrorCodes.SCENARIONOTSUPORTED_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    FORECASTINGCONFIG_ERROR = [
        ErrorCodes.FORECASTINGCONFIG_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    SPECIALCOLUMNDROP_ERROR = [
        ErrorCodes.SPECIALCOLUMNDROP_ERROR,
        ErrorCodes.FORECASTINGCONFIG_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    TIMEANDGRAINSOVERLAP_ERROR = [
        ErrorCodes.TIMEANDGRAINSOVERLAP_ERROR,
        ErrorCodes.FORECASTINGCONFIG_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    COLUMNNAMENOTSUPPORTED_ERROR = [
        ErrorCodes.COLUMNNAMENOTSUPPORTED_ERROR,
        ErrorCodes.FORECASTINGCONFIG_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    CONFIG_ERROR = [
        ErrorCodes.CONFIG_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    FEATURIZATIONOFF_ERROR = [
        ErrorCodes.FEATURIZATIONOFF_ERROR,
        ErrorCodes.CONFIG_ERROR,
        ErrorCodes.VALIDATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    AUTHENTICATION_ERROR = [
        ErrorCodes.AUTHENTICATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    AUTHORIZATION_ERROR = [
        ErrorCodes.AUTHORIZATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    FEATUREUNAVAILABLE_ERROR = [
        ErrorCodes.FEATUREUNAVAILABLE_ERROR,
        ErrorCodes.AUTHORIZATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    KEYBOARDEXCEPTION_ERROR = [
        ErrorCodes.KEYBOARDEXCEPTION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    EARLYTERMINATION_ERROR = [
        ErrorCodes.EARLYTERMINATION_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    INSUFFICIENTMEMORY_ERROR = [
        ErrorCodes.INSUFFICIENTMEMORY_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    DISKSPACEUNVAILABLE_ERROR = [
        ErrorCodes.DISKSPACEUNVAILABLE_ERROR,
        ErrorCodes.USER_ERROR,
    ]
    SYSTEM_ERROR = [
        ErrorCodes.SYSTEM_ERROR,
    ]
    PREDICTION_ERROR = [
        ErrorCodes.PREDICTION_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    EXTERNAL_ERROR = [
        ErrorCodes.EXTERNAL_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    FIT_ERROR = [
        ErrorCodes.FIT_ERROR,
        ErrorCodes.EXTERNAL_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    TRANSFORM_ERROR = [
        ErrorCodes.TRANSFORM_ERROR,
        ErrorCodes.EXTERNAL_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    DATA_ERROR = [
        ErrorCodes.DATA_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    RAWDATASNAPSHOT_ERROR = [
        ErrorCodes.RAWDATASNAPSHOT_ERROR,
        ErrorCodes.DATA_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    OS_ERROR = [
        ErrorCodes.OS_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    FILE_ERROR = [
        ErrorCodes.FILE_ERROR,
        ErrorCodes.OS_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    FILENOTFOUND_ERROR = [
        ErrorCodes.FILENOTFOUND_ERROR,
        ErrorCodes.FILE_ERROR,
        ErrorCodes.OS_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    DELETE_ERROR = [
        ErrorCodes.DELETE_ERROR,
        ErrorCodes.FILE_ERROR,
        ErrorCodes.OS_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    MEMORY_ERROR = [
        ErrorCodes.MEMORY_ERROR,
        ErrorCodes.OS_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    PROCESSKILLED_ERROR = [
        ErrorCodes.PROCESSKILLED_ERROR,
        ErrorCodes.OS_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    SERVICE_ERROR = [
        ErrorCodes.SERVICE_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    APIINVOCATION_ERROR = [
        ErrorCodes.APIINVOCATION_ERROR,
        ErrorCodes.SERVICE_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    JASMINESERVICE_ERROR = [
        ErrorCodes.JASMINESERVICE_ERROR,
        ErrorCodes.SERVICE_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    FETCHNEXTITERATION_ERROR = [
        ErrorCodes.FETCHNEXTITERATION_ERROR,
        ErrorCodes.JASMINESERVICE_ERROR,
        ErrorCodes.SERVICE_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    MISSINGSTATE_ERROR = [
        ErrorCodes.MISSINGSTATE_ERROR,
        ErrorCodes.SERVICE_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    INVALIDSTATE_ERROR = [
        ErrorCodes.INVALIDSTATE_ERROR,
        ErrorCodes.SERVICE_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    STATECHANGE_ERROR = [
        ErrorCodes.STATECHANGE_ERROR,
        ErrorCodes.SERVICE_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    DATASETSERVICE_ERROR = [
        ErrorCodes.DATASETSERVICE_ERROR,
        ErrorCodes.SERVICE_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    PIPELINEEXECUTION_ERROR = [
        ErrorCodes.PIPELINEEXECUTION_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    AUTOMLENSEMBLE_ERROR = [
        ErrorCodes.AUTOMLENSEMBLE_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    CLIENT_ERROR = [
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    TRANSFORMRUNTIME_ERROR = [
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    BADTRANSFORMARGUMENT_ERROR = [
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    INVALIDTRANSFORMARGUMENT_ERROR = [
        ErrorCodes.INVALIDTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    DATATRANSFORMERUNKNOWNTASK_ERROR = [
        ErrorCodes.DATATRANSFORMERUNKNOWNTASK_ERROR,
        ErrorCodes.INVALIDTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    MODELINGBERTNOAPEXINVALIDHIDDENSIZE_ERROR = [
        ErrorCodes.MODELINGBERTNOAPEXINVALIDHIDDENSIZE_ERROR,
        ErrorCodes.INVALIDTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    UNRECOGNIZEDTRANSFORMEDFEATURENAME_ERROR = [
        ErrorCodes.UNRECOGNIZEDTRANSFORMEDFEATURENAME_ERROR,
        ErrorCodes.INVALIDTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    UNRECOGNIZEDRAWFEATUREALIASNAME_ERROR = [
        ErrorCodes.UNRECOGNIZEDRAWFEATUREALIASNAME_ERROR,
        ErrorCodes.INVALIDTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    INVALIDTRANSFORMARGUMENTTYPE_ERROR = [
        ErrorCodes.INVALIDTRANSFORMARGUMENTTYPE_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    MODELINGBERTNOAPEXNOTINTORSTR_ERROR = [
        ErrorCodes.MODELINGBERTNOAPEXNOTINTORSTR_ERROR,
        ErrorCodes.INVALIDTRANSFORMARGUMENTTYPE_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    NIMBUSMLTEXTTARGETENCODERFEATURIZERINVALIDTYPE_ERROR = [
        ErrorCodes.NIMBUSMLTEXTTARGETENCODERFEATURIZERINVALIDTYPE_ERROR,
        ErrorCodes.INVALIDTRANSFORMARGUMENTTYPE_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    NIMBUSMLTEXTTARGETENCODERLEARNERINVALIDTYPE_ERROR = [
        ErrorCodes.NIMBUSMLTEXTTARGETENCODERLEARNERINVALIDTYPE_ERROR,
        ErrorCodes.INVALIDTRANSFORMARGUMENTTYPE_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    MALFORMEDTRANSFORMARGUMENT_ERROR = [
        ErrorCodes.MALFORMEDTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    ENGINEEREDFEATURENAMESNOTRANSFORMATIONSINJSON_ERROR = [
        ErrorCodes.ENGINEEREDFEATURENAMESNOTRANSFORMATIONSINJSON_ERROR,
        ErrorCodes.MALFORMEDTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    NOTSUPPORTEDTRANSFORMARGUMENT_ERROR = [
        ErrorCodes.NOTSUPPORTEDTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    ENGINEEREDFEATURENAMESUNSUPPORTEDINDEX_ERROR = [
        ErrorCodes.ENGINEEREDFEATURENAMESUNSUPPORTEDINDEX_ERROR,
        ErrorCodes.NOTSUPPORTEDTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    ENGINEEREDFEATURENAMESNOTSUPPORTEDFEATURETYPE_ERROR = [
        ErrorCodes.ENGINEEREDFEATURENAMESNOTSUPPORTEDFEATURETYPE_ERROR,
        ErrorCodes.NOTSUPPORTEDTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    PRETRAINEDTEXTDNNTRANSFORMERFITUNSUPPORTEDTASK_ERROR = [
        ErrorCodes.PRETRAINEDTEXTDNNTRANSFORMERFITUNSUPPORTEDTASK_ERROR,
        ErrorCodes.NOTSUPPORTEDTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    PRETRAINEDTEXTDNNTRANSFORMERCONVERTUNSUPPORTEDTASK_ERROR = [
        ErrorCodes.PRETRAINEDTEXTDNNTRANSFORMERCONVERTUNSUPPORTEDTASK_ERROR,
        ErrorCodes.NOTSUPPORTEDTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    BLANKOREMPTYTRANSFORMARGUMENT_ERROR = [
        ErrorCodes.BLANKOREMPTYTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    ENGINEEREDFEATURENAMESEMPTYJSON_ERROR = [
        ErrorCodes.ENGINEEREDFEATURENAMESEMPTYJSON_ERROR,
        ErrorCodes.BLANKOREMPTYTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    ENGINEEREDFEATURENAMESNORAWFEATURETYPE_ERROR = [
        ErrorCodes.ENGINEEREDFEATURENAMESNORAWFEATURETYPE_ERROR,
        ErrorCodes.BLANKOREMPTYTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    ENGINEEREDFEATURENAMESTRANSFORMERNAMESNOTFOUND_ERROR = [
        ErrorCodes.ENGINEEREDFEATURENAMESTRANSFORMERNAMESNOTFOUND_ERROR,
        ErrorCodes.BLANKOREMPTYTRANSFORMARGUMENT_ERROR,
        ErrorCodes.BADTRANSFORMARGUMENT_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    INVALIDTRANSFORMDATA_ERROR = [
        ErrorCodes.INVALIDTRANSFORMDATA_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    TRANSFORMDATASHAPE_ERROR = [
        ErrorCodes.TRANSFORMDATASHAPE_ERROR,
        ErrorCodes.INVALIDTRANSFORMDATA_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    DATATRANSFORMERINCONSISTENTROWCOUNT_ERROR = [
        ErrorCodes.DATATRANSFORMERINCONSISTENTROWCOUNT_ERROR,
        ErrorCodes.TRANSFORMDATASHAPE_ERROR,
        ErrorCodes.INVALIDTRANSFORMDATA_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    TRANSFORMERRUNTIMENOTCALLED_ERROR = [
        ErrorCodes.TRANSFORMERRUNTIMENOTCALLED_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    CATIMPUTERRUNTIMENOTCALLED_ERROR = [
        ErrorCodes.CATIMPUTERRUNTIMENOTCALLED_ERROR,
        ErrorCodes.TRANSFORMERRUNTIMENOTCALLED_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    CROSSVALIDATIONTARGETIMPUTERRUNTIMENOTCALLED_ERROR = [
        ErrorCodes.CROSSVALIDATIONTARGETIMPUTERRUNTIMENOTCALLED_ERROR,
        ErrorCodes.TRANSFORMERRUNTIMENOTCALLED_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    BINTRANSFORMERRUNTIMENOTCALLED_ERROR = [
        ErrorCodes.BINTRANSFORMERRUNTIMENOTCALLED_ERROR,
        ErrorCodes.TRANSFORMERRUNTIMENOTCALLED_ERROR,
        ErrorCodes.TRANSFORMRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    ONNXRUNTIME_ERROR = [
        ErrorCodes.ONNXRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    INVALIDONNXMODEL_ERROR = [
        ErrorCodes.INVALIDONNXMODEL_ERROR,
        ErrorCodes.ONNXRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    INVALIDONNXINPUTDATA_ERROR = [
        ErrorCodes.INVALIDONNXINPUTDATA_ERROR,
        ErrorCodes.ONNXRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
    INVALIDONNXINPUTDATATYPE_ERROR = [
        ErrorCodes.INVALIDONNXINPUTDATATYPE_ERROR,
        ErrorCodes.INVALIDONNXINPUTDATA_ERROR,
        ErrorCodes.ONNXRUNTIME_ERROR,
        ErrorCodes.CLIENT_ERROR,
        ErrorCodes.SYSTEM_ERROR,
    ]
